@@ -54,5 +54,5 @@ def get_component_manager(request: Request) -> Generator[ComponentManager, None,
 
     This is used as FastAPI dependency and called for every request.
     """
-    with ComponentManager(request) as component_manager:
+    with ComponentManager.from_request(request) as component_manager:
         yield component_manager
